/*
 * This file is part of SpongeAPI, licensed under the MIT License (MIT).
 *
 * Copyright (c) SpongePowered <https://www.spongepowered.org>
 * Copyright (c) contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.spongepowered.api.world.biome;

import org.spongepowered.api.util.generator.dummy.DummyObjectProvider;

/**
 * An enumeration of all possible {@link BiomeType}s available in vanilla
 * minecraft.
 */
public final class BiomeTypes {

    // Standard Biomes

    // SORTFIELDS:ON

    public static final BiomeType BEACH = DummyObjectProvider.createFor(BiomeType.class, "BEACH");

    public static final BiomeType BIRCH_FOREST = DummyObjectProvider.createFor(BiomeType.class, "BIRCH_FOREST");

    public static final BiomeType BIRCH_FOREST_HILLS = DummyObjectProvider.createFor(BiomeType.class, "BIRCH_FOREST_HILLS");

    public static final BiomeType COLD_BEACH = DummyObjectProvider.createFor(BiomeType.class, "COLD_BEACH");

    public static final BiomeType COLD_TAIGA = DummyObjectProvider.createFor(BiomeType.class, "COLD_TAIGA");

    public static final BiomeType COLD_TAIGA_HILLS = DummyObjectProvider.createFor(BiomeType.class, "COLD_TAIGA_HILLS");

    public static final BiomeType DEEP_OCEAN = DummyObjectProvider.createFor(BiomeType.class, "DEEP_OCEAN");

    public static final BiomeType DESERT = DummyObjectProvider.createFor(BiomeType.class, "DESERT");

    public static final BiomeType DESERT_HILLS = DummyObjectProvider.createFor(BiomeType.class, "DESERT_HILLS");

    public static final BiomeType EXTREME_HILLS = DummyObjectProvider.createFor(BiomeType.class, "EXTREME_HILLS");

    public static final BiomeType EXTREME_HILLS_EDGE = DummyObjectProvider.createFor(BiomeType.class, "EXTREME_HILLS_EDGE");

    public static final BiomeType EXTREME_HILLS_PLUS = DummyObjectProvider.createFor(BiomeType.class, "EXTREME_HILLS_PLUS");

    public static final BiomeType FOREST = DummyObjectProvider.createFor(BiomeType.class, "FOREST");

    public static final BiomeType FOREST_HILLS = DummyObjectProvider.createFor(BiomeType.class, "FOREST_HILLS");

    public static final BiomeType FROZEN_OCEAN = DummyObjectProvider.createFor(BiomeType.class, "FROZEN_OCEAN");

    public static final BiomeType FROZEN_RIVER = DummyObjectProvider.createFor(BiomeType.class, "FROZEN_RIVER");

    public static final BiomeType HELL = DummyObjectProvider.createFor(BiomeType.class, "HELL");

    public static final BiomeType ICE_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "ICE_MOUNTAINS");

    public static final BiomeType ICE_PLAINS = DummyObjectProvider.createFor(BiomeType.class, "ICE_PLAINS");

    public static final BiomeType JUNGLE = DummyObjectProvider.createFor(BiomeType.class, "JUNGLE");

    public static final BiomeType JUNGLE_EDGE = DummyObjectProvider.createFor(BiomeType.class, "JUNGLE_EDGE");

    public static final BiomeType JUNGLE_HILLS = DummyObjectProvider.createFor(BiomeType.class, "JUNGLE_HILLS");

    public static final BiomeType MEGA_TAIGA = DummyObjectProvider.createFor(BiomeType.class, "MEGA_TAIGA");

    public static final BiomeType MEGA_TAIGA_HILLS = DummyObjectProvider.createFor(BiomeType.class, "MEGA_TAIGA_HILLS");

    public static final BiomeType MESA = DummyObjectProvider.createFor(BiomeType.class, "MESA");

    public static final BiomeType MESA_PLATEAU = DummyObjectProvider.createFor(BiomeType.class, "MESA_PLATEAU");

    public static final BiomeType MESA_PLATEAU_FOREST = DummyObjectProvider.createFor(BiomeType.class, "MESA_PLATEAU_FOREST");

    public static final BiomeType MUSHROOM_ISLAND = DummyObjectProvider.createFor(BiomeType.class, "MUSHROOM_ISLAND");

    public static final BiomeType MUSHROOM_ISLAND_SHORE = DummyObjectProvider.createFor(BiomeType.class, "MUSHROOM_ISLAND_SHORE");

    public static final BiomeType OCEAN = DummyObjectProvider.createFor(BiomeType.class, "OCEAN");

    public static final BiomeType PLAINS = DummyObjectProvider.createFor(BiomeType.class, "PLAINS");

    public static final BiomeType RIVER = DummyObjectProvider.createFor(BiomeType.class, "RIVER");

    public static final BiomeType ROOFED_FOREST = DummyObjectProvider.createFor(BiomeType.class, "ROOFED_FOREST");

    public static final BiomeType SAVANNA = DummyObjectProvider.createFor(BiomeType.class, "SAVANNA");

    public static final BiomeType SAVANNA_PLATEAU = DummyObjectProvider.createFor(BiomeType.class, "SAVANNA_PLATEAU");

    public static final BiomeType SKY = DummyObjectProvider.createFor(BiomeType.class, "SKY");

    public static final BiomeType STONE_BEACH = DummyObjectProvider.createFor(BiomeType.class, "STONE_BEACH");

    public static final BiomeType SWAMPLAND = DummyObjectProvider.createFor(BiomeType.class, "SWAMPLAND");

    public static final BiomeType TAIGA = DummyObjectProvider.createFor(BiomeType.class, "TAIGA");

    public static final BiomeType TAIGA_HILLS = DummyObjectProvider.createFor(BiomeType.class, "TAIGA_HILLS");

    // SORTFIELDS:OFF

    // Mutated Biomes
    // SORTFIELDS:ON

    public static final BiomeType BIRCH_FOREST_HILLS_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "BIRCH_FOREST_HILLS_MOUNTAINS");

    public static final BiomeType BIRCH_FOREST_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "BIRCH_FOREST_MOUNTAINS");

    public static final BiomeType COLD_TAIGA_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "COLD_TAIGA_MOUNTAINS");

    public static final BiomeType DESERT_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "DESERT_MOUNTAINS");

    public static final BiomeType EXTREME_HILLS_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "EXTREME_HILLS_MOUNTAINS");

    public static final BiomeType EXTREME_HILLS_PLUS_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "EXTREME_HILLS_PLUS_MOUNTAINS");

    public static final BiomeType FLOWER_FOREST = DummyObjectProvider.createFor(BiomeType.class, "FLOWER_FOREST");

    public static final BiomeType ICE_PLAINS_SPIKES = DummyObjectProvider.createFor(BiomeType.class, "ICE_PLAINS_SPIKES");

    public static final BiomeType JUNGLE_EDGE_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "JUNGLE_EDGE_MOUNTAINS");

    public static final BiomeType JUNGLE_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "JUNGLE_MOUNTAINS");

    public static final BiomeType MEGA_SPRUCE_TAIGA = DummyObjectProvider.createFor(BiomeType.class, "MEGA_SPRUCE_TAIGA");

    public static final BiomeType MEGA_SPRUCE_TAIGA_HILLS = DummyObjectProvider.createFor(BiomeType.class, "MEGA_SPRUCE_TAIGA_HILLS");

    public static final BiomeType MESA_BRYCE = DummyObjectProvider.createFor(BiomeType.class, "MESA_BRYCE");

    public static final BiomeType MESA_PLATEAU_FOREST_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "MESA_PLATEAU_FOREST_MOUNTAINS");

    public static final BiomeType MESA_PLATEAU_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "MESA_PLATEAU_MOUNTAINS");

    public static final BiomeType ROOFED_FOREST_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "ROOFED_FOREST_MOUNTAINS");

    public static final BiomeType SAVANNA_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "SAVANNA_MOUNTAINS");

    public static final BiomeType SAVANNA_PLATEAU_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "SAVANNA_PLATEAU_MOUNTAINS");

    public static final BiomeType SUNFLOWER_PLAINS = DummyObjectProvider.createFor(BiomeType.class, "SUNFLOWER_PLAINS");

    public static final BiomeType SWAMPLAND_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "SWAMPLAND_MOUNTAINS");

    public static final BiomeType TAIGA_MOUNTAINS = DummyObjectProvider.createFor(BiomeType.class, "TAIGA_MOUNTAINS");

    public static final BiomeType VOID = DummyObjectProvider.createFor(BiomeType.class, "VOID");

    // SORTFIELDS:OFF

    private BiomeTypes() {
    }
}
